"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = runCommand;
var _fs = _interopRequireDefault(require("fs"));
var _rimraf = _interopRequireDefault(require("rimraf"));
var _Logger = _interopRequireWildcard(require("../Logger"));
var _domRunner = _interopRequireDefault(require("../domRunner"));
var _makeRequest = _interopRequireDefault(require("../makeRequest"));
var _pageRunner = _interopRequireDefault(require("../pageRunner"));
var _remoteRunner = _interopRequireDefault(require("../remoteRunner"));
var _uploadReport = _interopRequireDefault(require("../uploadReport"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function getStaticPlugin(plugins, config) {
  const staticPlugin = plugins.find(plugin => typeof plugin.generateStaticPackage === 'function');
  if (staticPlugin) {
    return staticPlugin;
  }
  if (config.generateStaticPackage) {
    return {
      generateStaticPackage: config.generateStaticPackage
    };
  }
  return null;
}
async function runCommand(sha, config, {
  only,
  link,
  message,
  isAsync
}) {
  const logger = new _Logger.default();
  const {
    apiKey,
    apiSecret,
    endpoint,
    project,
    plugins,
    pages
  } = config;
  _rimraf.default.sync(config.tmpdir);
  _fs.default.mkdirSync(config.tmpdir, {
    recursive: true
  });
  const staticPlugin = getStaticPlugin(plugins, config);
  let result;
  if (pages) {
    result = await (0, _pageRunner.default)(config, {
      isAsync
    });
  } else if (staticPlugin) {
    result = await (0, _remoteRunner.default)(config, staticPlugin, {
      isAsync
    });
  } else {
    result = await (0, _domRunner.default)(config, {
      only,
      isAsync
    });
  }
  if (isAsync) {
    logger.start(`${(0, _Logger.logTag)(project)}Creating async report for ${sha}...`);
    const allRequestIds = [];
    result.forEach(item => allRequestIds.push(...item.result));
    const response = await (0, _makeRequest.default)({
      url: `${endpoint}/api/async-reports/${sha}`,
      method: 'POST',
      json: true,
      body: {
        requestIds: allRequestIds,
        link,
        message,
        project
      }
    }, {
      endpoint,
      apiKey,
      apiSecret,
      retryCount: 3
    });
    const {
      id,
      url
    } = response;
    logger.success();
    logger.info(`${(0, _Logger.logTag)(project)}Async report (id=${id}): ${url}`);
  } else {
    logger.start(`${(0, _Logger.logTag)(project)}Uploading report for ${sha}...`);
    const {
      url
    } = await (0, _uploadReport.default)({
      snaps: result,
      sha,
      endpoint,
      apiKey,
      apiSecret,
      link,
      message,
      project
    });
    logger.success();
    logger.info(`${(0, _Logger.logTag)(project)}View results at ${url}`);
  }
  logger.info(`${(0, _Logger.logTag)(project)}Done ${sha}`);
}