"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loadUserConfig;
var _nodeFetch = _interopRequireDefault(require("node-fetch"));
var _requireRelative = _interopRequireDefault(require("require-relative"));
var _Logger = _interopRequireDefault(require("./Logger"));
var _WrappedError = _interopRequireDefault(require("./WrappedError"));
var defaultConfig = _interopRequireWildcard(require("./DEFAULTS"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
async function load(pathToConfigFile) {
  try {
    let userConfig = (0, _requireRelative.default)(pathToConfigFile, process.cwd());
    // await if the config is a function, async or not
    if (typeof userConfig === 'function') {
      userConfig = await userConfig();
    }
    return {
      ...defaultConfig,
      ...userConfig
    };
  } catch (e) {
    // We only check for the default config file here, so that a missing custom
    // config path isn't ignored.
    if (e.message && /Cannot find.*\.happo\.js/.test(e.message)) {
      return defaultConfig;
    }
    throw new Error(e);
  }
}
async function getPullRequestSecret({
  endpoint
}, prUrl) {
  const res = await (0, _nodeFetch.default)(`${endpoint}/api/pull-request-token`, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify({
      prUrl
    })
  });
  if (!res.ok) {
    throw new Error(`Failed to get pull request secret: ${res.status} - ${await res.text()}`);
  }
  const {
    secret
  } = await res.json();
  return secret;
}
function resolvePRLink(env = process.env) {
  const {
    GITHUB_EVENT_PATH
  } = env;
  if (GITHUB_EVENT_PATH) {
    // eslint-disable-next-line import/no-dynamic-require
    const ghEvent = require(GITHUB_EVENT_PATH);
    if (ghEvent.pull_request) {
      return ghEvent.pull_request.html_url;
    }
  }
}
async function loadUserConfig(pathToConfigFile, env = process.env) {
  const {
    CHANGE_URL,
    HAPPO_CONFIG_FILE
  } = env;
  if (HAPPO_CONFIG_FILE) {
    pathToConfigFile = HAPPO_CONFIG_FILE;
  }
  const config = await load(pathToConfigFile);
  if (!config.apiKey || !config.apiSecret) {
    const missing = [!config.apiKey ? 'apiKey' : null, !config.apiSecret ? 'apiSecret' : null].filter(Boolean).map(key => `\`${key}\``).join(' and ');
    const prUrl = CHANGE_URL || resolvePRLink(env);
    if (!prUrl) {
      throw new Error(`Missing ${missing} in your Happo config. Reference yours at https://happo.io/settings`);
    }
    try {
      // Reassign API tokens to temporary ones provided for the PR
      new _Logger.default().info(`Missing ${missing} in Happo config. Falling back to pull-request authentication.`);
      config.apiKey = prUrl;
      config.apiSecret = await getPullRequestSecret(config, prUrl);
    } catch (e) {
      throw new _WrappedError.default('Failed to obtain temporary pull-request token', e);
    }
  }
  if (!config.targets || Object.keys(config.targets).length === 0) {
    throw new Error('You need at least one target defined under `targets` in your Happo config. See https://github.com/happo/happo.io#targets for more info.');
  }
  const defaultKeys = Object.keys(defaultConfig);
  const usedKeys = Object.keys(config);
  usedKeys.forEach(key => {
    if (!defaultKeys.includes(key)) {
      new _Logger.default().warn(`Unknown config key used in .happo.js: "${key}"`);
    }
  });
  config.publicFolders.push(config.tmpdir);
  config.plugins.forEach(({
    publicFolders
  }) => {
    if (publicFolders) {
      config.publicFolders.push(...publicFolders);
    }
  });
  return config;
}