"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = pagesRunner;
var _Logger = _interopRequireWildcard(require("./Logger"));
var _constructReport = _interopRequireDefault(require("./constructReport"));
var _ensureTarget = _interopRequireDefault(require("./ensureTarget"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
async function pagesRunner({
  apiKey,
  apiSecret,
  endpoint,
  targets,
  pages,
  project
}, {
  isAsync
} = {}) {
  const logger = new _Logger.default();
  try {
    logger.info(`${(0, _Logger.logTag)(project)}Preparing job for remote execution...`);
    const outerStartTime = Date.now();
    const targetNames = Object.keys(targets);
    const tl = targetNames.length;
    logger.info(`${(0, _Logger.logTag)(project)}Generating screenshots in ${tl} target${tl > 1 ? 's' : ''}...`);
    const results = await Promise.all(targetNames.map(async name => {
      const startTime = Date.now();
      const result = await (0, _ensureTarget.default)(targets[name]).execute({
        targetName: name,
        asyncResults: isAsync,
        pages,
        apiKey,
        apiSecret,
        endpoint
      });
      logger.start(`  - ${name}`, {
        startTime
      });
      logger.success();
      return {
        name,
        result
      };
    }));
    logger.start(undefined, {
      startTime: outerStartTime
    });
    logger.success();
    if (isAsync) {
      return results;
    }
    return (0, _constructReport.default)(results);
  } catch (e) {
    logger.fail();
    throw e;
  }
}